@@ -2,4 +2,6 @@ use askama::Template;
 
 #[derive(Template)]
 #[template(path = "create.html")]
-pub struct CreateTemplate {}
+pub struct CreateTemplate {
+    pub private: bool,
+}
